@@ -3,6 +3,7 @@ import time
 from types import NoneType
 import requests
 from PythonAdvancedTyping import check_type
+from .serialize import class_str_serializer
 from ..enums.api_calls import HttpMethod
 
 
@@ -128,8 +129,12 @@ def api_call(
     while attempts_made < tries:
         attempts_made += 1
         try:
+            if body is None:
+                json_body: None = None
+            else:
+                json_body: str = json.dumps(body, default=class_str_serializer)
             response: requests.Response = requests.request(
-                method.name, url, headers=headers, params=params, json=body, timeout=timeout
+                method.name, url, headers=headers, params=params, data=json_body, timeout=timeout
             )
             if attempts_made < tries:
                 response.raise_for_status()
